"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const extendWithFirebaseConfig_1 = (0, tslib_1.__importDefault)(require("./extendWithFirebaseConfig"));
const tasks = (0, tslib_1.__importStar)(require("./tasks"));
const firebase_utils_1 = require("./firebase-utils");
/**
 * Cypress plugin which attaches tasks used by custom commands
 * and returns modified Cypress config. Modified config includes
 * env setting with values of Firebase specific environment variables
 * such as GCLOUD_PROJECT, FIREBASE_DATABASE_EMULATOR_HOST,
 * FIRESTORE_EMULATOR_HOST and FIREBASE_AUTH_EMULATOR_HOST.
 * @param cypressOnFunc - on function from cypress plugins file
 * @param cypressConfig - Cypress config
 * @param adminInstance - firebase-admin instance
 * @param overrideConfig - Override config for firebase instance
 * @returns Extended Cypress config
 */
function pluginWithTasks(cypressOnFunc, cypressConfig, adminInstance, overrideConfig) {
    var _a;
    // Only initialize admin instance if it hasn't already been initialized
    if (((_a = adminInstance.apps) === null || _a === void 0 ? void 0 : _a.length) === 0) {
        (0, firebase_utils_1.initializeFirebase)(adminInstance, overrideConfig);
    }
    const tasksWithFirebase = Object.keys(tasks).reduce((acc, taskName) => {
        acc[taskName] = (taskSettings) => {
            if (taskSettings === null || taskSettings === void 0 ? void 0 : taskSettings.uid) {
                return tasks[taskName](adminInstance, taskSettings.uid, taskSettings);
            }
            const { action, path: actionPath, options = {}, data } = taskSettings;
            return tasks[taskName](adminInstance, action, actionPath, options, data);
        };
        return acc;
    }, {});
    // Attach tasks to Cypress using on function
    cypressOnFunc('task', tasksWithFirebase);
    // Return extended config
    return (0, extendWithFirebaseConfig_1.default)(cypressConfig);
}
exports.default = pluginWithTasks;
